How-to guides
#############

.. toctree::
   :glob:
   :maxdepth: 2

   Manage python-libjuju <manage-python-libjuju>
   Manage clouds <manage-clouds>
   Manage credentials <manage-credentials>
   Manage controllers <manage-controllers>
   Manage users <manage-users>
   Manage SSH keys <manage-ssh-keys>
   Manage models <manage-models>
   Manage charms <manage-charms>
   Manage applications <manage-applications>
   Manage resources (charms) <manage-charm-resources>
   Manage actions <manage-actions>
   Manage relations <manage-relations>
   Manage offers <manage-offers>
   Manage units <manage-units>
   Manage secrets <manage-secrets>
   Manage secret backends <manage-secret-backends>
   Manage machines <manage-machines>
   Manage storage <manage-storage>
   Manage storage pools <manage-storage-pools>
   Manage spaces <manage-spaces>
